==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/admin/lang/dutch.php <==
<?
define("_TOP5_DESC","Top 5 meest getoonde artikelen");
define("_HOT5_DESC","Top 5 besproken artikelen");
define("_LASTC5_DESC","Laatste 5 opmerkingen");
define("_STORY_EXT","Uitgebreide config");
define("_STORY_LINK_INDEX","Indexen (links artikelen)");
define("_STORY_LINK_INDEX_ADD","Nieuwe index toevoegen");
define("_STORY_LINK_INDEX_KILL","Als een index wordt verwijderd worden alle onderliggende links ook verwijderd!");

define("_LINK_ANYONE","Iedereen mag toevoegen (moderated)");
define("_LINK_ONLYADMIN","Alleen webmaster mag toevoegen");
define("_LINK_FREE","Iedereen mag toevoegen");
# logs.php
define("_LOGS_NOTHING","Geen logs bijhouden");
define("_LOGS_RESET","Reset logs");

# layout.php
define("_LAYOUT_EDITOR","Layouteditor: ");
define("_LAYOUT_VIEW","Toon/laad");
define("_LAYOUT_KILL","Verwijder");
define("_LAYOUT_ADD","Toevoegen/updaten");
define("_LAYOUT_AUTHOR","Auteur");
define("_LAYOUT_DESC","Omschrijving");
define("_LAYOUT_BG","Achtergrondplaatje");
define("_LAYOUT_LOGO","Logo-icoon");
define("_LAYOUT_FONT","Lettertype");
define("_LAYOUT_WIDTH","Paginabreedte");

define("_LAYOUT_TITLE_COLOR","Tekstkleur titels");
define("_LAYOUT_BLOCK_WIDTH","Blokbreedte");
define("_LAYOUT_BLOCK_ALIGN","Standaard uitlijning van blokken");
define("_LAYOUT_THEME","Thema's/templates");
define("_LAYOUT_B_LEFT","Blok links");
define("_LAYOUT_B_RIGHT","Blok rechts");
define("_LAYOUT_ADDED","Layout toegevoegd als");
define("_NOTKILL","Je kunt de actieve layout niet verwijderen! Er zijn geen wijzigingen aangebracht.");

# for Log Messages
define("_UPDATE_STORY","Artikel bijgewerkt");
define("_REPOST_STORY","Artikel opnieuw gepost");
define("_UPDATE_BLOCK","Blok bijgewerkt");
define("_UPDATE_REPLY","Opmerking bijgewerkt");
define("_UPDATE_TOPIC","Onderwerp bijgewerkt");
define("_ADD_TOPIC","Nieuw onderwerp toegevoegd");
define("_ADD_POLL","Poll aangemaakt");
define("_ADD_BLOCK","Nieuw blok toegevoegd");
define("_UPDATE_POLL","Poll bijgewerkt");
define("_UPDATE_CATE","Linkcategorie bijgewerkt");
define("_LOG_RESET","Log reset");
define("_UPDATE_LAYOUT","Layout bijgewerkt");
define("_DELETE_LAYOUT","Layout verwijderd");
define("_UPDATE_SITE","Siteconfiguratie bijgewerkt.");
define("_UPDATE_STORY_CONF","Artikelconfiguratie bijgewerkt.");
define("_UPDATE_REPLY_CONF","Opmerkingconfiguratie bijgewerkt");
define("_UPDATE_EXT_CONF","Uitgebreide configuratie bijgewerkt.");
define("_DELETE_ITEM","Item verwijderd");
define("_UNABLE_DEL","Item kon niet worden verwijderd");
define("_DEL_POLL","Poll verwijderd");
define("_DEL_TOPIC","Onderwerp verwijderd");
define("_DEL_CATE","Linkcategorie verwijderd");

# for Additional Control Page
define("_SHOW_PTIME","Toon opbouwtijd op elke pagina");
define("_SHOW_NUM","Toon ID bij artikel");
define("_CATCH_REPLY","Alle opmerkingen naar de webmaster sturen");
define("_FORM_WRAP","Text area WRAP");
define("_QP_ENCODE","Quoted-Printable encodering bij het versturen van e-mail");
define("_USE_THEME","Keuzelijst layouts");
define("_THEMES","Welke layouts bezoekers kunnen kiezen");
define("_ANTI_SPAM","Woordenfilter inschakelen");
define("_ANTI_IP","IP blokkering");
define("_BLOCK_IP_LIST","Geblokkeerde IP-adressen");
define("_SPAM_LIST","Gefilterde woorden");
define("_BLOCK_LIST","Post geblokkeerde IP-adressen");
define("_SHOW_CONTACT","Toon link Contact in navigatiebar");
define("_CONT_ADD_TXT","Extra tekst voor de artikel-toevoegen pagina");
define("_LOGIN_AD_TXT","Extra tekst voor de loginpagina");
define("_TOTAL_COUNT_IN_TOPIC","Toon totalen aan artikelen en opmerkingen in onderwerp-blok");
define("_REPLY_HTML_PARSE_LEVEL","HTML filterniveau voor opmerkingen");
define("_REPLY_PAGES","Opmerkingen via pagina-systeem");
define("_FILE_CACHE","Gebruik file caching voor RDF,RSS,URL,INCLUDE");
define("_SHOW_IP","Toon IP-adressen in posts");
define("_ENABLE_BUTTON","Links naar vorige/volgende artikel tonen");
define("_ENABLE_DAY","Toon weekdag in oudere-artikelen blok");
define("_REREPLY","Opmerking e-mailen naar de verzender zelf");
define("_FEATURE_TITLE","Titel van het feature-blok");
define("_UC_SCORE","Login user scoring(bij opmerkingen)");

# topics.php
define("_TOPIC_IMAGE","Icoon");
define("_TOPIC_TITLE","Titel");
define("_TOPIC_ALTTAG","ALT-tag");
define("_TOPIC_RULE","Instellingen");
define("_TOPIC_KILL","Bij het verwijderen van een onderwerp worden alle artikelen in die categorie OOK verwijderd!");
define("_TOPIC_ADD","Toevoegen");
define("_TOPIC_IMG_NULL","geen icoon");
define("_TOPIC_NO_POST","Geen nieuwe posts");
define("_TOPIC_NO_COMMENT","Geen opmerkingen");

# http referer
define("_REFER_LIMIT","limiet");
define("_REFER_LIMIT_NO","oneindig");

# browser, os recored
define("_COUNTER","browser/os (stats) loggen");
define("_TIME_COUNTER","access teller op tijd");
define("_COUNT_INIT","initialisatie");

# menu block
define("_MENU_BLOCK","Locatie v/h hoofdmenu-blok");

# session
define("_SESSION","Gebruik sessies (zien wie online is)");
define("_SESSION_TMOUT","<font size=\"-1\">Gebruikers worden 'inactief' na: ");
define("_SESSION_MIN","minuten</font>");
define("_ONLY_SESSION","(werkt alleen als <a href=\"user-ext.php\">Sessie init</a> aan staat)");

# private msg
define("_PRIVATE_MSG","Privberichten");
define("_PRIV_MSG_LIMIT","Max. aantal berichten");

# user
define("_LEVEL","niveau");
define("_NORMAL_USER","Lid");
define("_MODERATOR","Moderator");
define("_SCORE_MODERATOR","Score Moderator");
define("_TOTAL","Totaal");
define("_USER_ADMIN","Ledenadmin");
define("_USER_ADD","Toevoegen");
define("_USER_FIND","Zoeken");
define("_USER_EDIT","Bewerken");
define("_USER_KILL","Verwijderen");
define("_SENDMAIL","lid via e-mail op de hoogte stellen");
define("_UPDATED_USERDB","ledeninfo bijgewerkt");
define("_USER_ADDED","nieuw lid toegevoegd.");
define("_USER_DELETED","lid verwijderd.");

# submit log
define("_UPDATED","bijgewerkt");

define("_MORECONFIG","meer");

# user-ext
define("_REGIST_METHOD","Check email address when registration");
define("_USER_IMG","Persoonlijk icoon");
define("_COOKIE_TIME","Automatisch uitloggen na");
define("_DAY","dagen");

define("_STORY_WATING","Geplande artikelen");
define("_NO_PROGRAM_STORY","Er staan geen artikelen in de planning.");
define("_AUTO_STORY","Artikel plannen");
define("_STORY_PROGRAM","Planning van artikel");
define("_PROGRAM_SAVED","Planning opgeslagen.");
define("_CURRENT_TIME","Huidige tijd");
define("_YEAR","jaar");
define("_UMONTH","maand");
define("_HOUR","uur");
define("_MINUTE","minuut");
define("_POSTING_TIME","gepost om");
define("_STORY_PROGRAM_EDITED","wijziging opgeslagen.");
define("_STORY_PROGRAM_DELETED","geprogrammeerd artikel verwijderd");

define("_BMARK_LIMIT","Max. aantal bookmarks");

# admin_msg.php
define("_ADMIN_MSG","Statisch artikel");
define("_ADMIN_MSG_EDIT","Bewerken");
define("_ADMIN_MSG_ADD","Toevoegen");
define("_DISPLAY","Actief");
define("_ACTIVE","Aan");
define("_INACTIVE","Uit");
define("_DISPLAY_TYPE","Type");
define("_EXPIRE","Verloopt");
define("_CONTENT","Inhoud");

define("_COPYRIGHT","Copyright");
define("_NOLOGIN_USER","Geen ledensysteem gebruiken/tonen");

# sql.php
define("_PHP_INFO","Toon phpinfo()");
define("_SQL_RUNTIME","Runtime information");
define("_SQL_SYSTEM_VAR","System variables");
define("_SQL_PROCESS","Running Processes");
define("_SQL_CHECK_TABLE","Controleer tabellen");
define("_SQL_REPAIR_TABLE","Repareer tabellen");
define("_SQL_OPTIMIZE_TABLE","Optimaliseer tabellen");
define("_SQL_BACKUP_TABLE","Backup tabellen");
define("_SQL_DOCUMENT","Documentatie");
define("_SQL_ADMIN","SQL beheer");

# navigator.php
define("_NAVIGATOR","Navigatiebar");
define("_NAVIG_TOP","Horizontale navigatiebalk");
define("_NAVIG_BLOCK","Navigatie-blok");
define("_NAVIG_MOVE","Verplaats");
define("_NAVIG_NAME","Link");
define("_NAVIG_ORDER","Sorteren");
define("_NAVIG_ADD","Link toevoegen");
define("_NAVIG_EDIT","Link bewerken");
define("_NAVIG_DISPLAY_NAME","Naam");
define("_NAVIG_URL","URL");

# faq.php
define("_NEW_FAQ","Nieuwe FAQ maken");
define("_FAQ_TITLE","FAQ titel");
define("_ADD_QA","Question & Answer toevoegen");
define("_EDIT_QA","Question & Answer bewerken");
define("_EDIT_FAQ","FAQ titel bewerken");

# htmltag.php
define("_HTML_OPTION","HTML-tag optie");
define("_HTML_OPTION1","Je moet meer dan 1 tag kiezen!");

# config-story.php
define("_HTML_PARSE_LEVEL","Standaard HTML filterniveau");
define("_RDF_USE","RDF/RSS exporteren");
define("_MAILING_USE","Mailinglijst");
define("_USER_PARSE","Selectie van HTML filterniveau toestaan");
define("_EXPORT_RDF_NOW","nu RDF/RSS exporteren");
define("_EXPORT_RDF_NOW1","RDF/RSS bestand gexporteerd.");
define("_THUMBNAIL","Create Thumbnail");
define("_IMAGICK","Imagick Program (Complete Path) Enter the Path to the convert program of imagick, normally /usr/bin/convert");
define("_MAX_PIC_PIXEL","Maximum Image Dimensions Here you can define the maximum allowed Image Dimension to be attached (Width x Height in pixels).");
define("_THUMB_SIZE","Thumb size (Width in pixel)");

# polls.php
define("_POLL_QUES","Vraag");
define("_POLL_ADD","Nieuwe poll toevoegen");
define("_POLL_DISP","Weergave");
define("_POLL_EXPIRE","verloopt na (dagen)");
define("_POLL_ANSWER","Antwoord");

# random_link.php
define("_RANDOM_LINK_ADD","Link toevoegen");
define("_RANDOM_LINK_EDIT","Link bewerken");
define("_RANDOM_LINK_TITLE","Naam");
define("_RANDOM_LINK_NUMS","Aantal getoonde links");
define("_RANDOM_LINK_HEAD","Bloktitel");
define("_RANDOM_LINK_SOURCE","Bron voor links");
define("_RLINK_PREF1","hier...");
define("_RLINK_PREF2","uit de db (linkentabel)");
define("_RLINK_PREF3","uit artikelen (gerelateerde links)");

# random_button.php
define("_RANDOM_BUTTON_ADD","Knop toevoegen");
define("_RANDOM_BUTTON_EDIT","Knop bewerken");
define("_RANDOM_BUTTON_ALT","ALT-tag");
define("_RANDOM_BUTTON_NUMS","Aantal getoonde knoppen");
define("_RANDOM_BUTTON_HEAD","Bloktitel");


# banners.php
define("_BANNER","Banners");
define("_BANNER_LOCATION","Banner locatie");
define("_BANNER_LOCATION_DESC","Je moet de variabele \"\$banner\" in \"header.tmpl\" of \"footer.tmpl\" toevoegen!");
define("_BANNER_ALT","ALT-tag");
define("_BANNER_ADD","Banner toevoegen");
define("_BANNER_EDIT","Banner bewerken");

# blocks.php
define("_BLOCK_STORY_ONLY","Toon dit blok alleen op de beginpagina");
define("_BLOCK_RDF_SUPP","Ondersteunt het RSS/RDF formaat.");
define("_BLOCK_INCLUDE","volledige URL of pad");
define("_BLOCK_CACHE","Cache tijd");
define("_BLOCK_CACHE_DESC","minuten / 0=geen cache");
define("_NOT_URL","Het pad of de URL kon niet worden gevonden");
define("_MAX_ITEMS","Max. aantal getoonde links");

# config-site.php
define("_UNIQUEKEY","Unieke sleutel");
define("_KEYDESC","De sleutel moet worden gewijzigd bij de installatie");

# lost files (attachment.php)
define("_LOST_FILES","Lost Files");
define("_LOST_FILES_DESC","Here you can delete attachment data from postings when the files are missing from your filesystem, and delete files that are no longer attached to any postings. You can download or view a file if you click on it; if no link is present, the file does not exist.");
define("_LOST_FILES1","Missing files");
define("_LOST_FILES2","Files are not assigned to an existing story.");
define("_LOST_FILES_DEL","Delete");
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/lang/dutch.php <==
<?
define("_TOP5_DESC","Top 5 meest getoonde artikelen");
define("_HOT5_DESC","Top 5 besproken artikelen");
define("_LASTC5_DESC","Laatste 5 opmerkingen");
define("_STORY_EXT","Uitgebreide config");
define("_STORY_LINK_INDEX","Indexen (links artikelen)");
define("_STORY_LINK_INDEX_ADD","Nieuwe index toevoegen");
define("_STORY_LINK_INDEX_KILL","Als een index wordt verwijderd worden alle onderliggende links ook verwijderd!");

define("_LINK_ANYONE","Iedereen mag toevoegen (moderated)");
define("_LINK_ONLYADMIN","Alleen webmaster mag toevoegen");
define("_LINK_FREE","Iedereen mag toevoegen");
# logs.php
define("_LOGS_NOTHING","Geen logs bijhouden");
define("_LOGS_RESET","Reset logs");

# layout.php
define("_LAYOUT_EDITOR","Layouteditor: ");
define("_LAYOUT_VIEW","Toon/laad");
define("_LAYOUT_KILL","Verwijder");
define("_LAYOUT_ADD","Toevoegen/updaten");
define("_LAYOUT_AUTHOR","Auteur");
define("_LAYOUT_DESC","Omschrijving");
define("_LAYOUT_BG","Achtergrondplaatje");
define("_LAYOUT_LOGO","Logo-icoon");
define("_LAYOUT_FONT","Lettertype");
define("_LAYOUT_WIDTH","Paginabreedte");

define("_LAYOUT_TITLE_COLOR","Tekstkleur titels");
define("_LAYOUT_BLOCK_WIDTH","Blokbreedte");
define("_LAYOUT_BLOCK_ALIGN","Standaard uitlijning van blokken");
define("_LAYOUT_THEME","Thema's/templates");
define("_LAYOUT_B_LEFT","Blok links");
define("_LAYOUT_B_RIGHT","Blok rechts");
define("_LAYOUT_ADDED","Layout toegevoegd als");
define("_NOTKILL","Je kunt de actieve layout niet verwijderen! Er zijn geen wijzigingen aangebracht.");

# for Log Messages
define("_UPDATE_STORY","Artikel bijgewerkt");
define("_REPOST_STORY","Artikel opnieuw gepost");
define("_UPDATE_BLOCK","Blok bijgewerkt");
define("_UPDATE_REPLY","Opmerking bijgewerkt");
define("_UPDATE_TOPIC","Onderwerp bijgewerkt");
define("_ADD_TOPIC","Nieuw onderwerp toegevoegd");
define("_ADD_POLL","Poll aangemaakt");
define("_ADD_BLOCK","Nieuw blok toegevoegd");
define("_UPDATE_POLL","Poll bijgewerkt");
define("_UPDATE_CATE","Linkcategorie bijgewerkt");
define("_LOG_RESET","Log reset");
define("_UPDATE_LAYOUT","Layout bijgewerkt");
define("_DELETE_LAYOUT","Layout verwijderd");
define("_UPDATE_SITE","Siteconfiguratie bijgewerkt.");
define("_UPDATE_STORY_CONF","Artikelconfiguratie bijgewerkt.");
define("_UPDATE_REPLY_CONF","Opmerkingconfiguratie bijgewerkt");
define("_UPDATE_EXT_CONF","Uitgebreide configuratie bijgewerkt.");
define("_DELETE_ITEM","Item verwijderd");
define("_UNABLE_DEL","Item kon niet worden verwijderd");
define("_DEL_POLL","Poll verwijderd");
define("_DEL_TOPIC","Onderwerp verwijderd");
define("_DEL_CATE","Linkcategorie verwijderd");

# for Additional Control Page
define("_SHOW_PTIME","Toon opbouwtijd op elke pagina");
define("_SHOW_NUM","Toon ID bij artikel");
define("_CATCH_REPLY","Alle opmerkingen naar de webmaster sturen");
define("_FORM_WRAP","Text area WRAP");
define("_QP_ENCODE","Quoted-Printable encodering bij het versturen van e-mail");
define("_USE_THEME","Keuzelijst layouts");
define("_THEMES","Welke layouts bezoekers kunnen kiezen");
define("_ANTI_SPAM","Woordenfilter inschakelen");
define("_ANTI_IP","IP blokkering");
define("_BLOCK_IP_LIST","Geblokkeerde IP-adressen");
define("_SPAM_LIST","Gefilterde woorden (regex)");
define("_BLOCK_LIST","Post geblokkeerde IP-adressen");
define("_SHOW_CONTACT","Toon link Contact in navigatiebar");
define("_CONT_ADD_TXT","Extra tekst voor de artikel-toevoegen pagina");
define("_LOGIN_AD_TXT","Extra tekst voor de loginpagina");
define("_TOTAL_COUNT_IN_TOPIC","Toon totalen aan artikelen en opmerkingen in onderwerp-blok");
define("_REPLY_HTML_PARSE_LEVEL","HTML filterniveau voor opmerkingen");
define("_REPLY_PAGES","Opmerkingen via pagina-systeem");
define("_FILE_CACHE","Gebruik file caching voor RDF,RSS,URL,INCLUDE");
define("_SHOW_IP","Toon IP-adressen in posts");
define("_ENABLE_BUTTON","Links naar vorige/volgende artikel tonen");
define("_ENABLE_DAY","Toon weekdag in oudere-artikelen blok");
define("_REREPLY","Opmerking e-mailen naar de verzender zelf");
define("_FEATURE_TITLE","Titel van het feature-blok");
define("_UC_SCORE","Login user scoring(bij opmerkingen)");
define("_RSS_POPWINDOW","Add \"target=_blank\" tag for rss block");

# topics.php
define("_TOPIC_IMAGE","Icoon");
define("_TOPIC_TITLE","Titel");
define("_TOPIC_ALTTAG","ALT-tag");
define("_TOPIC_RULE","Instellingen");
define("_TOPIC_KILL","Bij het verwijderen van een onderwerp worden alle artikelen in die categorie OOK verwijderd!");
define("_TOPIC_ADD","Toevoegen");
define("_TOPIC_IMG_NULL","geen icoon");
define("_TOPIC_NO_POST","Geen nieuwe posts");
define("_TOPIC_NO_COMMENT","Geen opmerkingen");

# http referer
define("_REFER_LIMIT","limiet");
define("_REFER_LIMIT_NO","oneindig");

# browser, os recored
define("_COUNTER","browser/os (stats) loggen");
define("_TIME_COUNTER","access teller op tijd");
define("_COUNT_INIT","initialisatie");

# menu block
define("_MENU_BLOCK","Locatie v/h hoofdmenu-blok");

# session
define("_SESSION","Gebruik sessies (zien wie online is)");
define("_SESSION_TMOUT","<font size=\"-1\">Gebruikers worden 'inactief' na: ");
define("_SESSION_MIN","minuten</font>");
define("_ONLY_SESSION","(werkt alleen als <a href=\"user-ext.php\">Sessie init</a> aan staat)");

# private msg
define("_PRIVATE_MSG","Privberichten");
define("_PRIV_MSG_LIMIT","Max. aantal berichten");

# user
define("_LEVEL","niveau");
define("_NORMAL_USER","Lid");
define("_MODERATOR","Moderator");
define("_SCORE_MODERATOR","Score Moderator");
define("_TOTAL","Totaal");
define("_USER_ADMIN","Ledenadmin");
define("_USER_ADD","Toevoegen");
define("_USER_FIND","Zoeken");
define("_USER_EDIT","Bewerken");
define("_USER_KILL","Verwijderen");
define("_SENDMAIL","lid via e-mail op de hoogte stellen");
define("_UPDATED_USERDB","ledeninfo bijgewerkt");
define("_USER_ADDED","nieuw lid toegevoegd.");
define("_USER_DELETED","lid verwijderd.");

# submit log
define("_UPDATED","bijgewerkt");

define("_MORECONFIG","meer");

# user-ext
define("_ONLINE_USER_INFO_DISPLAY","Display online user infomation");
define("_STORY_WATCH","Story Watching");
define("_REGIST_METHOD","Check email address when registration");
define("_USER_IMG","Persoonlijk icoon");
define("_COOKIE_TIME","Automatisch uitloggen na");
define("_DAY","dagen");

define("_STORY_WATING","Geplande artikelen");
define("_NO_PROGRAM_STORY","Er staan geen artikelen in de planning.");
define("_AUTO_STORY","Artikel plannen");
define("_STORY_PROGRAM","Planning van artikel");
define("_PROGRAM_SAVED","Planning opgeslagen.");
define("_CURRENT_TIME","Huidige tijd");
define("_YEAR","jaar");
define("_UMONTH","maand");
define("_HOUR","uur");
define("_MINUTE","minuut");
define("_POSTING_TIME","gepost om");
define("_STORY_PROGRAM_EDITED","wijziging opgeslagen.");
define("_STORY_PROGRAM_DELETED","geprogrammeerd artikel verwijderd");

define("_BMARK_LIMIT","Max. aantal bookmarks");

# admin_msg.php
define("_ADMIN_MSG","Statisch artikel");
define("_ADMIN_MSG_EDIT","Bewerken");
define("_ADMIN_MSG_ADD","Toevoegen");
define("_DISPLAY","Actief");
define("_ACTIVE","Aan");
define("_INACTIVE","Uit");
define("_DISPLAY_TYPE","Type");
define("_EXPIRE","Verloopt");
define("_CONTENT","Inhoud");

define("_COPYRIGHT","Copyright");
define("_NOLOGIN_USER","Geen ledensysteem gebruiken/tonen");

# sql.php
define("_PHP_INFO","Toon phpinfo()");
define("_SQL_RUNTIME","Runtime information");
define("_SQL_SYSTEM_VAR","System variables");
define("_SQL_PROCESS","Running Processes");
define("_SQL_CHECK_TABLE","Controleer tabellen");
define("_SQL_REPAIR_TABLE","Repareer tabellen");
define("_SQL_OPTIMIZE_TABLE","Optimaliseer tabellen");
define("_SQL_BACKUP_TABLE","Backup tabellen");
define("_SQL_DOCUMENT","Documentatie");
define("_SQL_ADMIN","SQL beheer");

# navigator.php
define("_NAVIGATOR","Navigatiebar");
define("_NAVIG_TOP","Horizontale navigatiebalk");
define("_NAVIG_BLOCK","Navigatie-blok");
define("_NAVIG_MOVE","Verplaats");
define("_NAVIG_NAME","Link");
define("_NAVIG_ORDER","Sorteren");
define("_NAVIG_ADD","Link toevoegen");
define("_NAVIG_EDIT","Link bewerken");
define("_NAVIG_DISPLAY_NAME","Naam");
define("_NAVIG_URL","URL");

# faq.php
define("_NEW_FAQ","Nieuwe FAQ maken");
define("_FAQ_TITLE","FAQ titel");
define("_ADD_QA","Question & Answer toevoegen");
define("_EDIT_QA","Question & Answer bewerken");
define("_EDIT_FAQ","FAQ titel bewerken");

# htmltag.php
define("_HTML_OPTION","HTML-tag optie");
define("_HTML_OPTION1","Je moet meer dan 1 tag kiezen!");

# config-story.php
define("_HTML_PARSE_LEVEL","Standaard HTML filterniveau");
define("_RDF_USE","RDF/RSS exporteren");
define("_MAILING_USE","Mailinglijst");
define("_USER_PARSE","Selectie van HTML filterniveau toestaan");
define("_EXPORT_RDF_NOW","nu RDF/RSS exporteren");
define("_EXPORT_RDF_NOW1","RDF/RSS bestand gexporteerd.");
define("_THUMBNAIL","Create Thumbnail");
define("_IMAGICK","Imagick Program (Complete Path) Enter the Path to the convert program of imagick, normally /usr/bin/convert");
define("_MAX_PIC_PIXEL","Maximum Image Dimensions Here you can define the maximum allowed Image Dimension to be attached (Width x Height in pixels).");
define("_THUMB_SIZE","Thumb size (Width in pixel)");
define("_NO_IMAGICK","Can not find convert binary!");

# polls.php
define("_POLL_QUES","Vraag");
define("_POLL_ADD","Nieuwe poll toevoegen");
define("_POLL_DISP","Weergave");
define("_POLL_EXPIRE","verloopt na (dagen)");
define("_POLL_ANSWER","Antwoord");

# random_link.php
define("_RANDOM_LINK_ADD","Link toevoegen");
define("_RANDOM_LINK_EDIT","Link bewerken");
define("_RANDOM_LINK_TITLE","Naam");
define("_RANDOM_LINK_NUMS","Aantal getoonde links");
define("_RANDOM_LINK_HEAD","Bloktitel");
define("_RANDOM_LINK_SOURCE","Bron voor links");
define("_RLINK_PREF1","hier...");
define("_RLINK_PREF2","uit de db (linkentabel)");
define("_RLINK_PREF3","uit artikelen (gerelateerde links)");

# random_button.php
define("_RANDOM_BUTTON_ADD","Knop toevoegen");
define("_RANDOM_BUTTON_EDIT","Knop bewerken");
define("_RANDOM_BUTTON_ALT","ALT-tag");
define("_RANDOM_BUTTON_NUMS","Aantal getoonde knoppen");
define("_RANDOM_BUTTON_HEAD","Bloktitel");


# banners.php
define("_BANNER","Banners");
define("_BANNER_LOCATION","Banner locatie");
define("_BANNER_LOCATION_DESC","Je moet de variabele \"\$banner\" in \"header.tmpl\" of \"footer.tmpl\" toevoegen!");
define("_BANNER_ALT","ALT-tag");
define("_BANNER_ADD","Banner toevoegen");
define("_BANNER_EDIT","Banner bewerken");

# blocks.php
define("_BLOCK_STORY_ONLY","Toon dit blok alleen op de beginpagina");
define("_BLOCK_RDF_SUPP","Ondersteunt het RSS/RDF formaat.");
define("_BLOCK_INCLUDE","volledige URL of pad");
define("_BLOCK_CACHE","Cache tijd");
define("_BLOCK_CACHE_DESC","minuten / 0=geen cache");
define("_NOT_URL","Het pad of de URL kon niet worden gevonden");
define("_MAX_ITEMS","Max. aantal getoonde links");

# config-site.php
define("_UNIQUEKEY","Unieke sleutel");
define("_KEYDESC","De sleutel moet worden gewijzigd bij de installatie");

# lost files (attachment.php)
define("_LOST_FILES","Lost Files");
define("_LOST_FILES_DESC","Here you can delete attachment data from postings when the files are missing from your filesystem, and delete files that are no longer attached to any postings. You can download or view a file if you click on it; if no link is present, the file does not exist.");
define("_LOST_FILES1","Missing files");
define("_LOST_FILES2","Files are not assigned to an existing story.");
define("_LOST_FILES_DEL","Delete");

# trackback msg
define("_TBMSG_LENGTH","tracked messages length");
define("_TBMSG_SHOW","showing tracked messages with comments.");
?>
